Package: RandomFields
Version: 3.3.14
Title: Simulation and Analysis of Random Fields
Author: Martin Schlather [aut, cre], Alexander Malinowski [aut], Marco Oesting [aut], Daphne Boecker [aut], Kirstin Strokorb [aut], Sebastian Engelke [aut], Johannes Martini [aut], Felix Ballani [aut], Olga Moreva [aut], Jonas Auel[ctr], Peter Menck [ctr], Sebastian Gross [ctr], Ulrike Ober [ctb], Paulo Ribeiro [ctb], Brian D. Ripley [ctb], Richard Singleton [ctb], Ben Pfaff [ctb], R Core Team [ctb]
Maintainer: Martin Schlather <schlather@math.uni-mannheim.de>
LinkingTo: RandomFieldsUtils
Depends: R (>= 3.5.0), sp, RandomFieldsUtils (>= 1.1)
Imports: graphics, methods, grDevices, stats, utils
Suggests: colorspace, RColorBrewer, mvtnorm, raster, tcltk2, tcltk,
        tkrplot, spam, tools, minqa, soma, optimx, nloptr, pso, GenSA
Description: Methods for the inference on and the simulation of Gaussian fields are provided. Furthermore, methods for the simulation of extreme value random fields are provided. Main geostatistical parts are based among others on the books by Christian Lantuejoul <doi:10.1007/978-3-662-04808-5>.
Collate: aaa_auto.R aaa_globals.R basic.fctns.R bigdata.R Class.R
        convert_new.R convert.R Crossvalidation.R datasets.R D.H.R
        fitbernoulli.R fitbr.R fitgauss.R fitmaxstable.R fitpoisson.R
        getNset.R helmholz.R internal_use.R kriging.R Likelihoodratio.R
        Methods-aux.R Methods-RFsp.R obsolete.R
        RFempvario-Methods-plots.R RFempvario.R RFfit.R RFgui.R
        rf-plots.R rf.R RMmodels-Methods-plots.R RMmodelsBasics.R
        RMmodels.R RMmodelsConvenience.R RMmodelsSpecial.R RQmodels.R
        generatemodels.R zzz.R
License: GPL (>= 3)
URL: https://www.wim.uni-mannheim.de/schlather/publications/software
Packaged: 2022-01-17 02:19:22 UTC; schlather
NeedsCompilation: yes
Repository: CRAN
Date/Publication: 2022-01-18 19:12:52 UTC
