# This file has been created automatically by 'rfGenerateMaths'
asin <- function(x) if (is(x, ZF_MODEL)) R.asin(x) else base::asin(x)
atan <- function(x) if (is(x, ZF_MODEL)) R.atan(x) else base::atan(x)
atan2 <- function(y, x) if (is(y, ZF_MODEL)) R.atan2(y, x) else base::atan2(y, x)
cos <- function(x) if (is(x, ZF_MODEL)) R.cos(x) else base::cos(x)
sin <- function(x) if (is(x, ZF_MODEL)) R.sin(x) else base::sin(x)
tan <- function(x) if (is(x, ZF_MODEL)) R.tan(x) else base::tan(x)
acosh <- function(x) if (is(x, ZF_MODEL)) R.acosh(x) else base::acosh(x)
asinh <- function(x) if (is(x, ZF_MODEL)) R.asinh(x) else base::asinh(x)
atanh <- function(x) if (is(x, ZF_MODEL)) R.atanh(x) else base::atanh(x)
cosh <- function(x) if (is(x, ZF_MODEL)) R.cosh(x) else base::cosh(x)
sinh <- function(x) if (is(x, ZF_MODEL)) R.sinh(x) else base::sinh(x)
tanh <- function(x) if (is(x, ZF_MODEL)) R.tanh(x) else base::tanh(x)
exp <- function(x) if (is(x, ZF_MODEL)) R.exp(x) else base::exp(x)
log <- function(x) if (is(x, ZF_MODEL)) R.log(x) else base::log(x)
expm1 <- function(x) if (is(x, ZF_MODEL)) R.expm1(x) else base::expm1(x)
log1p <- function(x) if (is(x, ZF_MODEL)) R.log1p(x) else base::log1p(x)
logb <- function(x) if (is(x, ZF_MODEL)) R.logb(x) else base::logb(x)
log2 <- function(x) if (is(x, ZF_MODEL)) R.log2(x) else base::log2(x)
sqrt <- function(x) if (is(x, ZF_MODEL)) R.sqrt(x) else base::sqrt(x)
abs <- function(x) if (is(x, ZF_MODEL)) R.fabs(x) else base::abs(x)
floor <- function(x) if (is(x, ZF_MODEL)) R.floor(x) else base::floor(x)
round <- function(x, ...) if (is(x, ZF_MODEL)) R.round(x, ...) else base::round(x, ...)
trunc <- function(x) if (is(x, ZF_MODEL)) R.trunc(x) else base::trunc(x)
gamma <- function(x) if (is(x, ZF_MODEL)) R.gamma(x) else base::gamma(x)
lgamma <- function(x) if (is(x, ZF_MODEL)) R.lgamma(x) else base::lgamma(x)
max <- function(...) if (is(list(...)[[1]], ZF_MODEL)) R.fmax(...) else base::max(...)
min <- function(...) if (is(list(...)[[1]], ZF_MODEL)) R.fmin(...) else base::min(...)
