% M-x auto-fill-mode

\newcommand{\litIntro}{Schlather, M. (1999) \emph{An introduction to positive definite functions and to unconditional simulation of random fields.} Technical report ST 99-10, Dept. of Maths and Statistics, Lancaster University.}

\newcommand{\litLantue}{ Lantuejoul, Ch. (2002) \emph{Geostatistical simulation.} \bold{New York:} Springer.}

\newcommand{\lit}{}

\newcommand{\lit}{}

\newcommand{\lit}{}

\newcommand{\lit}{}

\newcommand{\lit}{}

\newcommand{\lit}{}

